summaryrefslogtreecommitdiffstats
path: root/src/qtattributionsscanner/package.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/qtattributionsscanner/package.h')
-rw-r--r--src/qtattributionsscanner/package.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/qtattributionsscanner/package.h b/src/qtattributionsscanner/package.h
index 5cf624307..31d95c9fb 100644
--- a/src/qtattributionsscanner/package.h
+++ b/src/qtattributionsscanner/package.h
@@ -35,7 +35,8 @@
struct Package {
QString id; // Usually a lowercase, no-spaces version of the name. Mandatory.
QString path; // Source directory. Optional.
- // Default is the directory of the qt_attribution.json ile.
+ // Default is the directory of the qt_attribution.json file.
+ QStringList files; // Files in path. Optional.
QString name; // Descriptive name of the package. Will be used as the title. Mandatory.
QString qdocModule; // QDoc module where the documentation should be included. Mandatory.
QString qtUsage; // How the package is used in Qt. Any way to disable? Mandatory.